@@ -16,7 +16,7 @@
 
 __docformat__ = "google"
 
-from typing import TYPE_CHECKING, Dict, List, Optional, TextIO, Tuple, Union, cast
+from typing import TYPE_CHECKING, Optional, TextIO, cast
 
 from .lazy_import import lazy_import
 
@@ -38,9 +38,8 @@ import contextlib
 import itertools
 
 from . import config as _mod_config
-from . import debug, errors, registry, repository
+from . import debug, errors, registry, repository, urlutils
 from . import revision as _mod_revision
-from . import urlutils
 from .controldir import (
     ControlComponent,
     ControlComponentFormat,
@@ -90,13 +89,13 @@ class Branch(ControlComponent):
 
     controldir: ControlDir
 
-    name: Optional[str]
+    name: str | None
 
     base: str
 
     _format: "BranchFormat"
 
-    _last_revision_info_cache: Optional[Tuple[int, RevisionID]]
+    _last_revision_info_cache: tuple[int, RevisionID] | None
 
     repository: repository.Repository
 
@@ -106,12 +105,12 @@ class Branch(ControlComponent):
     def user_transport(self) -> Transport:
         return self.controldir.user_transport
 
-    def __init__(self, possible_transports: Optional[List[Transport]] = None) -> None:
+    def __init__(self, possible_transports: list[Transport] | None = None) -> None:
         self.tags = self._format.make_tags(self)
         self._revision_history_cache = None
         self._revision_id_to_revno_cache = None
-        self._partial_revision_id_to_revno_cache: Dict[RevisionID, int] = {}
-        self._partial_revision_history_cache: List[RevisionID] = []
+        self._partial_revision_id_to_revno_cache: dict[RevisionID, int] = {}
+        self._partial_revision_history_cache: list[RevisionID] = []
         self._last_revision_info_cache = None
         self._master_branch_cache = None
         self._merge_sorted_revisions_cache = None
@@ -149,10 +148,10 @@ class Branch(ControlComponent):
 
     def _extend_partial_history(
         self,
-        stop_index: Optional[int] = None,
-        stop_revision: Optional[RevisionID] = None,
+        stop_index: int | None = None,
+        stop_revision: RevisionID | None = None,
     ) -> None:
-        """Extend the partial history to include a given index
+        """Extend the partial history to include a given index.
 
         If a stop_index is supplied, stop when that index has been reached.
         If a stop_revision is supplied, stop when that revision is
@@ -201,11 +200,11 @@ class Branch(ControlComponent):
     @staticmethod
     def open_from_transport(
         transport: Transport,
-        name: Optional[str] = None,
+        name: str | None = None,
         _unsupported: bool = False,
         possible_transports=None,
     ):
-        """Open the branch rooted at transport"""
+        """Open the branch rooted at transport."""
         control = ControlDir.open_from_transport(transport, _unsupported)
         return control.open_branch(
             name=name, unsupported=_unsupported, possible_transports=possible_transports
@@ -356,7 +355,7 @@ class Branch(ControlComponent):
         raise NotImplementedError(self.unlock)
 
     def peek_lock_mode(self):
-        """Return lock mode for the Branch: 'r', 'w' or None"""
+        """Return lock mode for the Branch: 'r', 'w' or None."""
         raise NotImplementedError(self.peek_lock_mode)
 
     def get_physical_lock_status(self):
@@ -546,7 +545,7 @@ class Branch(ControlComponent):
             if direction == "forward":
                 return reversed(list(filtered))
             else:
-                raise ValueError("invalid direction %r" % direction)
+                raise ValueError("invalid direction {!r}".format(direction))
 
     def _filter_merge_sorted_revisions(
         self, merge_sorted_revisions, start_revision_id, stop_revision_id, stop_rule
@@ -617,7 +616,7 @@ class Branch(ControlComponent):
                             reached_stop_revision_id = True
                             revision_id_whitelist.extend(rev.parent_ids)
         else:
-            raise ValueError("invalid stop_rule %r" % stop_rule)
+            raise ValueError("invalid stop_rule {!r}".format(stop_rule))
 
     def _filter_start_non_ancestors(self, rev_iter):
         # If we started from a dotted revno, we want to consider it as a tip
@@ -718,7 +717,7 @@ class Branch(ControlComponent):
                 stop_revision, limit=limit, lossy=lossy
             )
 
-    def get_bound_location(self) -> Optional[str]:
+    def get_bound_location(self) -> str | None:
         """Return the URL of the branch we are bound to.
 
         Older format branches cannot bind, please be sure to use a metadir
@@ -727,7 +726,7 @@ class Branch(ControlComponent):
         return None
 
     def get_old_bound_location(self):
-        """Return the URL of the branch we used to be bound to"""
+        """Return the URL of the branch we used to be bound to."""
         raise errors.UpgradeRequired(self.user_url)
 
     def get_commit_builder(
@@ -754,7 +753,6 @@ class Branch(ControlComponent):
           lossy: Whether to discard data that can not be natively
             represented, when pushing to a foreign VCS
         """
-
         if config_stack is None:
             config_stack = self.get_config_stack()
 
@@ -771,7 +769,7 @@ class Branch(ControlComponent):
         )
 
     def get_master_branch(
-        self, possible_transports: Optional[List[Transport]] = None
+        self, possible_transports: list[Transport] | None = None
     ) -> Optional["Branch"]:
         """Return the branch we are bound to.
 
@@ -790,7 +788,7 @@ class Branch(ControlComponent):
         raise NotImplementedError(self.get_stacked_on_url)
 
     def set_last_revision_info(
-        self, revno: Optional[int], revision_id: RevisionID
+        self, revno: int | None, revision_id: RevisionID
     ) -> None:
         """Set the last revision of this branch.
 
@@ -807,10 +805,10 @@ class Branch(ControlComponent):
     def generate_revision_history(
         self,
         revision_id: RevisionID,
-        last_rev: Optional[RevisionID] = None,
+        last_rev: RevisionID | None = None,
         other_branch: Optional["Branch"] = None,
     ) -> None:
-        """See Branch.generate_revision_history"""
+        """See Branch.generate_revision_history."""
         with self.lock_write():
             graph = self.repository.get_graph()
             (last_revno, last_revid) = self.last_revision_info()
@@ -825,10 +823,10 @@ class Branch(ControlComponent):
             revno = graph.find_distance_to_null(revision_id, known_revision_ids)
             self.set_last_revision_info(revno, revision_id)
 
-    def _set_parent_location(self, url: Optional[str]) -> None:
+    def _set_parent_location(self, url: str | None) -> None:
         raise NotImplementedError(self._set_parent_location)
 
-    def set_parent(self, url: Optional[str]) -> None:
+    def set_parent(self, url: str | None) -> None:
         """See Branch.set_parent."""
         # TODO: Maybe delete old location files?
         # URLs should never be unicode, even on the local fs,
@@ -840,7 +838,7 @@ class Branch(ControlComponent):
                     url.encode("ascii")
                 except UnicodeEncodeError as exc:
                     raise urlutils.InvalidURL(
-                        url, "Urls must be 7-bit ascii, " "use breezy.urlutils.escape"
+                        url, "Urls must be 7-bit ascii, use breezy.urlutils.escape"
                     ) from exc
             url = urlutils.relative_url(self.base, url)
         with self.lock_write():
@@ -907,7 +905,7 @@ class Branch(ControlComponent):
         """
         raise NotImplementedError(self._gen_revision_history)
 
-    def _revision_history(self) -> List[RevisionID]:
+    def _revision_history(self) -> list[RevisionID]:
         if "evil" in debug.debug_flags:
             mutter_callsite(3, "revision_history scales with history.")
         if self._revision_history_cache is not None:
@@ -933,7 +931,7 @@ class Branch(ControlComponent):
         """Return last revision id, or NULL_REVISION."""
         return self.last_revision_info()[1]
 
-    def last_revision_info(self) -> Tuple[int, RevisionID]:
+    def last_revision_info(self) -> tuple[int, RevisionID]:
         """Return information about the last revision.
 
         Returns: A tuple (revno, revision_id).
@@ -968,7 +966,7 @@ class Branch(ControlComponent):
         return (revno, revid)
 
     def revision_id_to_revno(self, revision_id: RevisionID) -> int:
-        """Given a revision id, return its revno"""
+        """Given a revision id, return its revno."""
         if _mod_revision.is_null(revision_id):
             return 0
         history = self._revision_history()
@@ -978,7 +976,7 @@ class Branch(ControlComponent):
             raise errors.NoSuchRevision(self, revision_id) from exc
 
     def get_rev_id(
-        self, revno: int, history: Optional[List[RevisionID]] = None
+        self, revno: int, history: list[RevisionID] | None = None
     ) -> RevisionID:
         """Find the revision id of the specified revno."""
         with self.lock_read():
@@ -999,8 +997,8 @@ class Branch(ControlComponent):
         source: "Branch",
         *,
         overwrite: bool = False,
-        stop_revision: Optional[RevisionID] = None,
-        possible_transports: Optional[List[Transport]] = None,
+        stop_revision: RevisionID | None = None,
+        possible_transports: list[Transport] | None = None,
         **kwargs,
     ) -> "PullResult":
         """Mirror source into this branch.
@@ -1021,7 +1019,7 @@ class Branch(ControlComponent):
         target: "Branch",
         *,
         overwrite: bool = False,
-        stop_revision: Optional[RevisionID] = None,
+        stop_revision: RevisionID | None = None,
         lossy: bool = False,
         **kwargs,
     ):
@@ -1037,7 +1035,7 @@ class Branch(ControlComponent):
         """Return `Tree` object for last revision."""
         return self.repository.revision_tree(self.last_revision())
 
-    def get_parent(self) -> Optional[str]:
+    def get_parent(self) -> str | None:
         """Return the parent location of the branch.
 
         This is the default location for pull/missing.  The usual
@@ -1068,26 +1066,26 @@ class Branch(ControlComponent):
             url = urlutils.relative_url(self.base, url)
         config.set(name, url)
 
-    def _get_config_location(self, name: str, *, config=None) -> Optional[str]:
+    def _get_config_location(self, name: str, *, config=None) -> str | None:
         if config is None:
             config = self.get_config_stack()
         location = config.get(name)
         if location == "":
             location = None
-        return cast(Optional[str], location)
+        return cast("str | None", location)
 
-    def get_child_submit_format(self) -> Optional[str]:
+    def get_child_submit_format(self) -> str | None:
         """Return the preferred format of submissions to this branch."""
-        return cast(Optional[str], self.get_config_stack().get("child_submit_format"))
+        return cast("str | None", self.get_config_stack().get("child_submit_format"))
 
-    def get_submit_branch(self) -> Optional[str]:
+    def get_submit_branch(self) -> str | None:
         """Return the submit location of the branch.
 
         This is the default location for bundle.  The usual
         pattern is that the user can override it by specifying a
         location.
         """
-        return cast(Optional[str], self.get_config_stack().get("submit_branch"))
+        return cast("str | None", self.get_config_stack().get("submit_branch"))
 
     def set_submit_branch(self, location: str) -> None:
         """Return the submit location of the branch.
@@ -1098,7 +1096,7 @@ class Branch(ControlComponent):
         """
         self.get_config_stack().set("submit_branch", location)
 
-    def get_public_branch(self) -> Optional[str]:
+    def get_public_branch(self) -> str | None:
         """Return the public location of the branch.
 
         This is used by merge directives.
@@ -1114,9 +1112,9 @@ class Branch(ControlComponent):
         """
         self._set_config_location("public_branch", location)
 
-    def get_push_location(self) -> Optional[str]:
+    def get_push_location(self) -> str | None:
         """Return None or the location to push this branch to."""
-        return cast(str, self.get_config_stack().get("push_location"))
+        return cast("str", self.get_config_stack().get("push_location"))
 
     def set_push_location(self, location: str) -> None:
         """Set a new push location for this branch."""
@@ -1160,7 +1158,7 @@ class Branch(ControlComponent):
     def check_real_revno(self, revno: int) -> None:
         """\
         Check whether a revno corresponds to a real revision.
-        Zero (the NULL revision) is considered invalid
+        Zero (the NULL revision) is considered invalid.
         """
         if revno < 1 or revno > self.revno():
             raise errors.InvalidRevisionNumber(revno)
@@ -1169,8 +1167,8 @@ class Branch(ControlComponent):
         self,
         to_controldir: ControlDir,
         *,
-        revision_id: Optional[RevisionID] = None,
-        name: Optional[str] = None,
+        revision_id: RevisionID | None = None,
+        name: str | None = None,
         repository_policy=None,
         tag_selector=None,
     ) -> "Branch":
@@ -1669,7 +1667,7 @@ class BranchFormat(ControlComponentFormat):
         return self.get_format_description().rstrip()
 
     def supports_tags(self):
-        """True if this format supports tags stored in the branch"""
+        """True if this format supports tags stored in the branch."""
         return False  # by default
 
     def tags_are_versioned(self):
@@ -1994,7 +1992,7 @@ class _Result:
         if not getattr(self, "tag_conflicts", None):
             return
         to_file.write("Conflicting tags:\n")
-        for name, value1, value2 in self.tag_conflicts:
+        for name, _value1, _value2 in self.tag_conflicts:
             to_file.write("    {}\n".format(name))
 
 
@@ -2015,15 +2013,15 @@ class PullResult(_Result):
       tag_updates: A dict with new tags, see BasicTags.merge_to
     """
 
-    old_revno: Union[int, property]
-    new_revno: Union[int, property]
+    old_revno: int | property
+    new_revno: int | property
     old_revid: RevisionID
     new_revid: RevisionID
     source_branch: Branch
     master_branch: Branch
-    local_branch: Optional[Branch]
+    local_branch: Branch | None
     target_branch: Branch
-    tag_conflicts: List["TagConflict"]
+    tag_conflicts: list["TagConflict"]
     tag_updates: "TagUpdates"
 
     def report(self, to_file: TextIO) -> None:
@@ -2031,9 +2029,9 @@ class PullResult(_Result):
         tag_updates = getattr(self, "tag_updates", None)
         if not is_quiet():
             if self.old_revid != self.new_revid:
-                to_file.write("Now on revision %d.\n" % self.new_revno)
+                to_file.write(f"Now on revision {self.new_revno}.\n")
             if tag_updates:
-                to_file.write("%d tag(s) updated.\n" % len(tag_updates))
+                to_file.write(f"{len(tag_updates)} tag(s) updated.\n")
             if self.old_revid == self.new_revid and not tag_updates:
                 if not tag_conflicts:
                     to_file.write("No revisions or tags to pull.\n")
@@ -2069,7 +2067,7 @@ class BranchPushResult(_Result):
     source_branch: Branch
     master_branch: Branch
     target_branch: Branch
-    local_branch: Optional[Branch]
+    local_branch: Branch | None
 
     def report(self, to_file: TextIO) -> None:
         from breezy.i18n import gettext, ngettext
@@ -2119,7 +2117,7 @@ class BranchCheckResult:
           verbose: Requests more detailed display of what was checked,
             if any.
         """
-        from breezy.i18n import gettext, ngettext
+        from breezy.i18n import gettext
 
         note(
             gettext("checked branch {0} format {1}").format(
@@ -2154,8 +2152,8 @@ class InterBranch(InterObject[Branch]):
     def pull(
         self,
         overwrite: bool = False,
-        stop_revision: Optional[RevisionID] = None,
-        possible_transports: Optional[List[Transport]] = None,
+        stop_revision: RevisionID | None = None,
+        possible_transports: list[Transport] | None = None,
         local: bool = False,
         tag_selector=None,
     ) -> PullResult:
@@ -2170,9 +2168,9 @@ class InterBranch(InterObject[Branch]):
     def push(
         self,
         overwrite: bool = False,
-        stop_revision: Optional[RevisionID] = None,
+        stop_revision: RevisionID | None = None,
         lossy: bool = False,
-        _override_hook_source_branch: Optional[Branch] = None,
+        _override_hook_source_branch: Branch | None = None,
         tag_selector=None,
     ):
         """Mirror the source branch into the target branch.
@@ -2182,7 +2180,7 @@ class InterBranch(InterObject[Branch]):
         raise NotImplementedError(self.push)
 
     def copy_content_into(self, revision_id=None, tag_selector=None):
-        """Copy the content of source into target
+        """Copy the content of source into target.
 
         Args:
           revision_id:
@@ -2195,8 +2193,8 @@ class InterBranch(InterObject[Branch]):
 
     def fetch(
         self,
-        stop_revision: Optional[RevisionID] = None,
-        limit: Optional[int] = None,
+        stop_revision: RevisionID | None = None,
+        limit: int | None = None,
         lossy: bool = False,
     ) -> repository.FetchResult:
         """Fetch revisions.
@@ -2214,7 +2212,7 @@ class InterBranch(InterObject[Branch]):
 
     @classmethod
     def get(self, source: Branch, target: Branch) -> "InterBranch":
-        return cast(InterBranch, super().get(source, target))
+        return cast("InterBranch", super().get(source, target))
 
 
 def _fix_overwrite_type(overwrite):
@@ -2246,7 +2244,7 @@ class GenericInterBranch(InterBranch):
         return format
 
     def copy_content_into(self, revision_id=None, tag_selector=None):
-        """Copy the content of source into target
+        """Copy the content of source into target.
 
         revision_id: if not None, the revision history in the new branch will
                      be truncated to end with revision_id.
