@@ -24,9 +24,7 @@ import stat
 from collections import deque
 from functools import partial
 from io import BytesIO
-from typing import Union
 
-from dulwich import __version__ as dulwich_version
 from dulwich.config import ConfigFile as GitConfigFile
 from dulwich.config import parse_submodules
 from dulwich.diff_tree import RenameDetector, tree_changes
@@ -340,7 +338,7 @@ class GitTree(_mod_tree.Tree):
     def reference_parent(self, path):
         from ..branch import Branch
 
-        (url, section) = self._submodule_info()[encode_git_path(path)]
+        (url, _section) = self._submodule_info()[encode_git_path(path)]
         return Branch.open(url.decode("utf-8"))
 
 
@@ -429,7 +427,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         change_scanner = self._repository._file_change_scanner
         if self.commit_id == ZERO_SHA:
             return NULL_REVISION
-        (store, unused_path, commit_id) = change_scanner.find_last_change_revision(
+        (_store, _unused_path, commit_id) = change_scanner.find_last_change_revision(
             encode_git_path(path), self.commit_id
         )
         return self.mapping.revision_id_foreign_to_bzr(commit_id)
@@ -439,7 +437,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         if self.commit_id == ZERO_SHA:
             return NULL_REVISION
         try:
-            (store, unused_path, commit_id) = change_scanner.find_last_change_revision(
+            (store, _unused_path, commit_id) = change_scanner.find_last_change_revision(
                 encode_git_path(path), self.commit_id
             )
         except KeyError:
@@ -497,14 +495,14 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         return (store, mode, hexsha)
 
     def is_executable(self, path):
-        (store, mode, hexsha) = self._lookup_path(path)
+        (_store, mode, _hexsha) = self._lookup_path(path)
         if mode is None:
             # the tree root is a directory
             return False
         return mode_is_executable(mode)
 
     def kind(self, path):
-        (store, mode, hexsha) = self._lookup_path(path)
+        (_store, mode, _hexsha) = self._lookup_path(path)
         if mode is None:
             # the tree root is a directory
             return "directory"
@@ -690,7 +688,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         return osutils.sha_string(self.get_file_text(path))
 
     def get_file_verifier(self, path, stat_value=None):
-        (store, mode, hexsha) = self._lookup_path(path)
+        (_store, _mode, hexsha) = self._lookup_path(path)
         return ("GIT", hexsha)
 
     def get_file_size(self, path):
@@ -717,7 +715,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
 
     def get_reference_revision(self, path):
         """See RevisionTree.get_symlink_target."""
-        (store, mode, hexsha) = self._lookup_path(path)
+        (_store, mode, hexsha) = self._lookup_path(path)
         if S_ISGITLINK(mode):
             try:
                 nested_repo = self._get_submodule_repository(encode_git_path(path))
@@ -835,9 +833,19 @@ def tree_delta_from_git_changes(
         source_extras = set()
     ret = delta.TreeDelta()
     added = []
-    for change_type, old, new in changes:
-        (oldpath, oldmode, oldsha) = old
-        (newpath, newmode, newsha) = new
+    for change in changes:
+        change_type = change.type
+        old = change.old
+        new = change.new
+
+        if old is not None:
+            (oldpath, oldmode, oldsha) = old
+        else:
+            (oldpath, oldmode, oldsha) = (None, None, None)
+        if new is not None:
+            (newpath, newmode, newsha) = new
+        else:
+            (newpath, newmode, newsha) = (None, None, None)
         if newpath == b"" and not include_root:
             continue
         copied = change_type == "copy"
@@ -997,11 +1005,22 @@ def changes_from_git_changes(
         target_extras = set()
     if source_extras is None:
         source_extras = set()
-    for change_type, old, new in changes:
+    for change in changes:
+        change_type = change.type
+        old = change.old
+        new = change.new
+
         if change_type == "unchanged" and not include_unchanged:
             continue
-        (oldpath, oldmode, oldsha) = old
-        (newpath, newmode, newsha) = new
+
+        if old is not None:
+            (oldpath, oldmode, oldsha) = old
+        else:
+            (oldpath, oldmode, oldsha) = (None, None, None)
+        if new is not None:
+            (newpath, newmode, newsha) = new
+        else:
+            (newpath, newmode, newsha) = (None, None, None)
         if oldpath is not None:
             oldpath_decoded = decode_git_path(oldpath)
         else:
@@ -1200,14 +1219,6 @@ class InterGitTrees(_mod_tree.InterTree):
                 want_unchanged=want_unchanged,
                 change_type_same=True,
             )
-            # Convert TreeChange named tuples to plain tuples for dulwich >= 0.22.0
-            if dulwich_version >= (0, 22, 0):
-                changes = (
-                    (c.type,
-                     (c.old.path, c.old.mode, c.old.sha) if c.old else (None, None, None),
-                     (c.new.path, c.new.mode, c.new.sha) if c.new else (None, None, None))
-                    for c in changes
-                )
             return changes, from_extras, to_extras
 
     def find_target_path(self, path, recurse="none"):
@@ -1243,12 +1254,15 @@ class InterGitTrees(_mod_tree.InterTree):
         paths = set(paths)
         ret = {}
         changes = self._iter_git_changes(specific_files=paths, include_trees=False)[0]
-        for _change_type, old, new in changes:
-            if new[0] is None:
+        for change in changes:
+            old = change.old
+            new = change.new
+
+            if new is None or new.path is None:
                 continue
-            newpath = decode_git_path(new[0])
+            newpath = decode_git_path(new.path)
             if newpath in paths:
-                ret[newpath] = decode_git_path(old[0]) if old[0] else None
+                ret[newpath] = decode_git_path(old.path) if old and old.path else None
         for path in paths:
             if path not in ret:
                 if self.target.has_filename(path):
@@ -1357,7 +1371,7 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
             # caring about the instantaneous file kind within a uncommmitted tree
             #
             self._gather_kinds(files, kinds)
-            for path, kind in zip(files, kinds):
+            for path, kind in zip(files, kinds, strict=False):
                 path, can_access = osutils.normalized_filename(path)
                 if not can_access:
                     raise errors.InvalidNormalization(path)
@@ -1563,9 +1577,9 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
         self,
         name: str,
         path: str,
-        value: Union[IndexEntry, ConflictedIndexEntry],
+        value: IndexEntry | ConflictedIndexEntry,
         parent_id,
-    ) -> Union[GitTreeSymlink, GitTreeDirectory, GitTreeFile, GitTreeSubmodule]:
+    ) -> GitTreeSymlink | GitTreeDirectory | GitTreeFile | GitTreeSubmodule:
         if not isinstance(name, str):
             raise TypeError(name)
         if not isinstance(path, str):
@@ -1746,7 +1760,7 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
                         )
                     raise
             if kind != "directory":
-                (index, from_index_path) = self._lookup_index(from_path)
+                (index, _from_index_path) = self._lookup_index(from_path)
                 try:
                     self._index_del_entry(index, from_path)
                 except KeyError:
@@ -1933,12 +1947,12 @@ def snapshot_workingtree(
                 blobs[path] = (live_entry.sha, cleanup_mode(live_entry.mode))
     if want_unversioned:
         for extra in target._iter_files_recursive(include_dirs=False):  # type: ignore
-            extra, accessible = osutils.normalized_filename(extra)
+            extra, _accessible = osutils.normalized_filename(extra)
             np = encode_git_path(extra)
             if np in blobs:
                 continue
             st = target._lstat(extra)  # type: ignore
-            obj: Union[Tree, Blob]
+            obj: Tree | Blob
             if stat.S_ISDIR(st.st_mode):
                 obj = Tree()
             elif stat.S_ISREG(st.st_mode) or stat.S_ISLNK(st.st_mode):
