@@ -16,18 +16,15 @@
 
 """Tests of the parent related functions of WorkingTrees."""
 
-from breezy import (
-    uncommit,
-    )
+from breezy import uncommit
 from breezy.tests.per_workingtree import TestCaseWithWorkingTree
 
 
 class TestUncommit(TestCaseWithWorkingTree):
-
     def test_uncommit_to_null(self):
-        tree = self.make_branch_and_tree('branch')
+        tree = self.make_branch_and_tree("branch")
         tree.lock_write()
-        revid = tree.commit('a revision')
+        tree.commit("a revision")
         tree.unlock()
         uncommit.uncommit(tree.branch, tree=tree)
         self.assertEqual([], tree.get_parent_ids())
